@@ -10,7 +10,8 @@ def _flag_FIELD_as_stale(self, field=None, and_recalculate=None, commit=True):
         and_recalculate = True
         if hasattr(settings, 'CACHED_FIELD_EAGER_RECALCULATION'):
             and_recalculate = settings.CACHED_FIELD_EAGER_RECALCULATION
-    #:MC: this could be improved by checking the database instead of the object, but doing so would add a query per flag
+    #:MC: this could be improved by checking the database instead of the
+    #     object, but doing so would add a query per flag
     if not getattr(self, field.recalculation_needed_field_name):
         setattr(self, field.recalculation_needed_field_name, True)
         kwargs = {field.recalculation_needed_field_name: True}
@@ -64,7 +65,8 @@ def _set_FIELD(self, val, field=None):
 
 
 def trigger_cache_recalculation(self):
-    offload_cache_recalculation.delay(type(self)._meta.app_label, type(self)._meta.object_name, self.pk)
+    offload_cache_recalculation.delay(
+        type(self)._meta.app_label, type(self)._meta.object_name, self.pk)
 
 
 def ensure_class_has_cached_field_methods(cls):
@@ -98,8 +100,8 @@ class CachedFieldMixin(object):
       `calculation_method_name' to specify a method other than calculate_FIELD
       `cached_field_name' to specify a field name other than cached_FIELD
       `recalculation_needed_field_name' to specify a field name other than
-      `temporal_triggers' to turn on expirations
         FIELD_recalculation_needed
+      `temporal_triggers' to turn on expirations
     """
 
     def __init__(self, calculation_method_name=None, cached_field_name=None,
